<?php

namespace Drupal\texts;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerAwareTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the access control handler for the string translation entity type.
 */
class TextsContext implements ContainerAwareInterface {

  use ContainerAwareTrait;
  use StringTranslationTrait;

  protected $entityTypeManager;

  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getContextOptions() {
    $options = ['default' => $this->t('Default')];
    $storage = $this->entityTypeManager->getStorage('taxonomy_term');
    $terms = $storage->loadByProperties(['vid' => 'context_texts']);
    foreach ($terms as $term) {
      $options[$term->field_code->value] = $term->label();
    }
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public static function getStaticContextOptions() {
    $options = ['default' => t('Default')];
    $storage = \Drupal::service('entity_type.manager')->getStorage('taxonomy_term');
    $terms = $storage->loadByProperties(['vid' => 'context_texts']);
    foreach ($terms as $term) {
      $options[$term->field_code->value] = $term->label();
    }
    return $options;
  }

}
